////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////

package edu.uiuc.jdbv;

import edu.uiuc.jdbv.diagram.Diagram;
import edu.uiuc.jdbv.gui.JDBVMenuBar;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.event.*;



/**
 * Defines the action for auto arranging tables in a diagram
 *
 * @author Aleksandra Faust
 * @version $Revision: 1.6 $
 */
public class AutoArrangeAction extends AbstractAction implements ChangeListener
{
    /** The short descriptive text of this action = "Auto Arrange" */
    public static final String NAME_VALUE = "Auto Arrange";

    /** The mnemonic keycode = KeyEvent.VK_I */
    public static final int MNEMONIC_CODE = KeyEvent.VK_N;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Auto arranges tables in a diagram.";

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Auto-Arrange";


    /** The JDBV application instance that created this AutoArrangeAction */
    private JDBV jdbv;

    /** Our checkbox menu item */
    private JCheckBoxMenuItem checkboxMenuItem;


    /** Constructor that takes the JDBV application instance */
    public AutoArrangeAction ( JDBV jdbv )
    {
        super( NAME_VALUE );

        // Setup the action parameters
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        this.jdbv = jdbv;
		
        setEnabled( false );
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
        Diagram diagram = jdbv.getCurrentDiagram();
        if( diagram != null ) {
            // reverse the Auto Arrange mode
            diagram.setAutoArrangeMode(! diagram.getAutoArrangeMode());
        }	
	    
    }


    /**
     * Will only return a single menu item with repeated calls. Be sure not
     * to reuse the item
     */
    public JMenuItem getMenuItem()
    {
        if (checkboxMenuItem == null) {
            checkboxMenuItem = new JCheckBoxMenuItem( this );
        } // end of if ()

        return (checkboxMenuItem);
    }



    public void stateChanged(ChangeEvent e) {
	updateState();
    }



    public void updateState() {
	Diagram diagram = jdbv.getCurrentDiagram();
        if (diagram == null) {
            setEnabled( false );

            if (checkboxMenuItem != null) {
                checkboxMenuItem.setSelected( false );
            } // end of if ()
        } else {
            setEnabled( true );

            if (checkboxMenuItem != null) {
                checkboxMenuItem.setSelected( diagram.getAutoArrangeMode());
            } // end of if ()
        } // end of else
    }

}

