////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import java.awt.print.*;
import java.awt.event.*;
import org.apache.log4j.*;
import javax.swing.*;

/**
 * Brings up a dialog for setting the page format
 *
 * @author Ross Paul
 * @version $Revision: 1.6 $
 */

class PageSetupAction extends AbstractAction
{
    /** The logger to be used for the file = jdbv.PageSetup */
    private static final Logger logger = 
        Logger.getLogger( "jdbv.PageSetupAction" );

    /** The short descriptive name = "Page Setup ..." */
    public static final String NAME_VALUE = "Page Setup ...";
    
    /** The mnemonic keycode = KeyEvent.VK_G */
    public static final int MNEMONIC_CODE = KeyEvent.VK_G;

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/pageSetup16.gif" ));


   /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Set the page properties for printing";

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Page Setup";

    /** Handle to the singleton JDBV */
    private JDBV jdbv;

    /** 
     * Constructor takes an instance of JDBV.  Action is disabled whenever a 
     * diagram is not visible.
     */
    public PageSetupAction( JDBV jdbv )
    {
        super( NAME_VALUE );
        
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        this.jdbv = jdbv;
        setEnabled( true );
    }

    /** Brings up the print dialog */
    public void actionPerformed( ActionEvent e )
    {
        PrintAction.pageFormat = 
            PrinterJob.getPrinterJob().pageDialog( PrintAction.pageFormat );
    }
}
