////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import java.awt.*;
import java.awt.print.*;
import java.awt.event.*;
import org.apache.log4j.*;
import edu.uiuc.jdbv.util.PrintUtilities;
import edu.uiuc.jdbv.diagram.Diagram;

/**
 * Prints the current Diagram
 *
 * @author Ross Paul
 * @version $Revision: 1.9 $
 */

class PrintAction extends AbstractAction
{
    /** The logger to be used for the file = jdbv.JDBV */
    private static final Logger logger = Logger.getLogger("jdbv.PrintAction");

    /** The short descriptive name = "Print ..." */
    public static final String NAME_VALUE = "Print ...";
    
    /** The mnemonic keycode = KeyEvent.VK_P */
    public static final int MNEMONIC_CODE = KeyEvent.VK_P;

   /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Print Current Diagram";

    /** The keystroke key-code = java.awt.event.KeyEevnt.VK_P */
    public static final int KEY_STROKE_CODE = KeyEvent.VK_P;

    /** The keystroke modifier mask = Event.CTRL_MASK */
    public static final int KEY_STROKE_MODIFIERS = Event.CTRL_MASK;

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/print16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Print";

    /** Page format to use for printing */
    public static PageFormat pageFormat;

    /** Handle to the singleton JDBV */
    private JDBV jdbv;

    /** 
     * Constructor takes an instance of JDBV.  Action is disabled whenever a 
     * diagram is not visible.
     */
    public PrintAction( JDBV jdbv )
    {
        super( NAME_VALUE );
        
        // Setup action parameters
        KeyStroke keyStroke = 
            KeyStroke.getKeyStroke( KEY_STROKE_CODE, KEY_STROKE_MODIFIERS );
        putValue( ACCELERATOR_KEY, keyStroke );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        pageFormat = PrinterJob.getPrinterJob().defaultPage();

	this.jdbv = jdbv;
	setEnabled( false );
    }

    /** 
     * Attempts to print when selected.
     */
    public void actionPerformed( ActionEvent e )
    {
        PrinterJob printJob = PrinterJob.getPrinterJob();
        Diagram diagram = jdbv.getCurrentDiagram();
        boolean gridVisible = diagram.isGridVisible();
        diagram.setGridVisible( false );
   
        double zoomScale = diagram.getScale();
        diagram.setScale( 1.0 );

        printJob.setPrintable( new PrintUtilities( diagram ),
                               pageFormat );

        if (printJob.printDialog()){
            try { 
                printJob.print();
            } catch(PrinterException pe) {
                logger.error("Error printing", pe);
            } 
        }
        diagram.setGridVisible( gridVisible );
        diagram.setScale( zoomScale );
    }
}
