////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import javax.swing.undo.*;
import javax.swing.event.*;
import java.awt.event.*;

import edu.uiuc.jdbv.*;
import edu.uiuc.jdbv.gui.*;
import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;

/**
 * Defines the action for deleting the currently-selected table from a diagram
 *
 * @author Brian Sidharta
 * @author Ross Paul
 * @version $Revision: 1.6 $
 */
class RemoveTableAction extends AbstractAction
{
    /** The short descriptive text of this action = "New Diagram" */
    public static final String NAME_VALUE = "Remove Table";

    /** The mnemonic keycode = KeyEvent.VK_I */
//     public static final int MNEMONIC_CODE = KeyEvent.VK_N;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Removes the currently selected table from the diagram.";

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = 
        "Remove table from diagram";

    public static final String CONFIRM_REMOVE_MESSAGE =
        "Remove this table from the diagram?";

    public static final String CONFIRM_REMOVE_TITLE =
        "dbViZ Confirm";

    public static final String TABLE_REMOVED_STATUS =
        "Table removed: ";


    /** The JDBV application instance that created this ImportSchemaAction */
    private JDBV jdbv;



    /** Constructor that takes the JDBV application instance */
    public RemoveTableAction( JDBV jdbv)
    {
        super( NAME_VALUE );
        this.jdbv = jdbv;

        // Setup the action parameters
//         putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

    }

    /** Removeds a tabel from the specified diagram
     * @param diagram the diagram the table should be removed from
     * @param table the table being removed
     */
   public void removeTable(Diagram currentDiagram, Table table)
    {
	StatusBar statbar = JDBV.getInstance().MAIN_WINDOW.getStatusBar();
        statbar.setStatus( TABLE_REMOVED_STATUS + table.getName());
        currentDiagram.removeTable( table );
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
        Diagram currentDiagram = jdbv.MAIN_WINDOW.getDiagramPane().
            getCurrentDiagram();
        if( currentDiagram != null ) {
            TableList tableList = jdbv.MAIN_WINDOW.getTableList();
            Table item = (Table)tableList.getSelectedValue();

            if( item == null ) {
                System.err.println( "ERROR: No table selected to remove!" );
                return;
            }
	    
	    removeTable( currentDiagram, item ); 

	    jdbv.undoableEditHappened
		( new UndoableEditEvent( this, new UndoRemoveTable
					 ( currentDiagram, item )));
        }
    }

    /** Class which is used to undo table removal */
    private class UndoRemoveTable extends AbstractUndoableEdit
    {
	private Table table;
	private Diagram diagram;

	public UndoRemoveTable(Diagram diagram, Table table)
	{
	    this.table = table;
	    this.diagram = diagram;
	}

	public String getPresentationName()
	{
	    return NAME_VALUE + ": " + table.getName();
	}
	
	public void redo()
	{
	    super.redo();
	    removeTable( diagram, table );
	}


	public void undo()
	{
	    super.undo();
	    StatusBar statbar = JDBV.getInstance().MAIN_WINDOW.getStatusBar();
	    statbar.setStatus( AddTableAction.TABLE_ADDED_STATUS +
			       table.getName() );
	    diagram.addTable( table );
	}
    }

}




