////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import edu.uiuc.jdbv.util.SuffixFileFilter;

import edu.uiuc.jdbv.diagram.Diagram;

/**
 * Defines the action for saving a loaded diagram
 *
 * @author Uday Kale
 * @author Brian Sidharta
 * @version $Revision: 1.9 $
 */
class SaveAsDiagramAction extends AbstractSaveAction implements ChangeListener
{
    /** The short descriptive text of this action = "Save As" */
    public static final String NAME_VALUE = "Save As...";

    /** The mnemonic keycode = KeyEvent.VK_I */
    public static final int MNEMONIC_CODE = KeyEvent.VK_A;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE =
        "Saves a diagram to a new file.";

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/saveAs16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Save As";

    /** Constructor that takes the JDBV application instance */
    public SaveAsDiagramAction( JDBV jdbv )
    {
        super( NAME_VALUE, jdbv );

        // Setup the action parameters
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

	updateState();
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
        initiate();
    }

    /**
     * INitiates this action.
     * @return whether the file was saved successfully
     */
    public boolean initiate()
    {
        Diagram diagram = jdbv.getCurrentDiagram();

        if (diagram == null) { // No current diagram; quit
            return false;
        } // end of if ()
        
        String filename = showSaveDialog();
	if (filename == null)
	    return false;

        try {
            diagram.setFilename( filename );
            saveDiagram(diagram);
            return (true);
        } catch (Exception e) {
            e.printStackTrace();
            return (false);
        } // end of try-catch
    }

    public void stateChanged(ChangeEvent e) {
	updateState();
    }

    public void updateState() {
	Diagram diagram = jdbv.getCurrentDiagram();
	setEnabled(diagram != null);
    }
}
