////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import edu.uiuc.jdbv.diagram.Diagram;
import edu.uiuc.jdbv.gui.StatusBar;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.event.*;



/**
 * Defines the action for zooming out of the diagram
 *
 * @author Brian Schoudel
 * @version $Revision: 1.6 $
 */
class ZoomNormalAction extends AbstractAction implements ChangeListener
{
    /** The short descriptive text of this action = "Zoom Normal" */
    public static final String NAME_VALUE = "Zoom Normal";

    /** The mnemonic keycode = KeyEvent.VK_X */
    public static final int MNEMONIC_CODE = KeyEvent.VK_Z;

   /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = "Zoom Normal";

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/zoom16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Zoom Normal";

    /** The JDBV application instance that created this ZoomOutAction */
    private JDBV jdbv;


    private Diagram diagram = null;


    /** Constructor that takes the JDBV application instance */
    public ZoomNormalAction( JDBV jdbv )
    {
        super( NAME_VALUE );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );
        this.jdbv = jdbv;
        updateState();
        
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
	StatusBar statbar = jdbv.getInstance().MAIN_WINDOW.getStatusBar();
        Diagram diagram = jdbv.getCurrentDiagram();
        if( diagram != null ) {
            // zoom out
            double normalScale = 1.0;
            diagram.setScale( normalScale );
            statbar.setZoom( normalScale );
	}	
    }


    /** ChangeListener: updates enabled state */
    public void updateState()
    {
        diagram = jdbv.getCurrentDiagram();
	setEnabled( diagram != null );
    }

    /** for ChangeListener */
    public void stateChanged(ChangeEvent e) {
        updateState();
    }


}

