////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.diagram.xmlPersist;

import edu.uiuc.jdbv.diagram.*;
import edu.uiuc.jdbv.schema.*;

import java.util.*;

import java.beans.*;

/**
 * Persistence Delegate that handles Schemas
 * @author Uday Kale
 * @version $Revision: 1.4 $
 */
public class SchemaPersistenceDelegate extends PersistenceDelegate
{

    protected Expression instantiate( Object oldInstance, Encoder out )
    {
        if (oldInstance.getClass() != Schema.class) { 
            throw new IllegalArgumentException( "Expected a Schema " +
                                                "as oldInstance!" );
        }

        Schema schem = (Schema)oldInstance;
        Object[] constructorArgs = new Object[] { schem.getName() };
        return (new Expression( schem, Schema.class, "new", constructorArgs ));
    }


    protected void initialize(Class type, Object oldInstance, 
                              Object newInstance, Encoder out) 
    {
        super.initialize(type, oldInstance, newInstance, out);


        Schema schema = (Schema)oldInstance;
        List connList = new ArrayList( 10 );

        // Save the tables map
        Table[] tabs = schema.getTables();
        for (int i = 0; i < tabs.length; i++) {
            Object[] args = {tabs[i]};
            out.writeStatement(new Statement(oldInstance, "addTable", args));
            connList.addAll( Arrays.asList( tabs[i].getStartingConnections()));
        } // end of for ()
        
        // Write all the connections
        for (Iterator it = connList.iterator(); it.hasNext();) {
            Object[] args = {it.next()};
            out.writeStatement( new Statement( oldInstance,
                                               "addConnection", 
                                               args ));
        } // end of for ()
    }


    
}

