////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.diagram.xmlPersist;

import java.beans.*;
import edu.uiuc.jdbv.schema.*;

/**
 * Persistence Delegate that handles Tables
 * @author Brian Sidharta
 * @author Uday Kale
 * @version $Revision: 1.6 $
 */
public class TablePersistenceDelegate extends PersistenceDelegate
{

    protected Expression instantiate( Object oldInstance, Encoder out )
    {
        if (oldInstance.getClass() != Table.class) { 
            throw new IllegalArgumentException( "Expected a Table " +
                                                "as oldInstance!" );
        }

        Table tab = (Table)oldInstance;
        Object[] constructorArgs = new Object[] { tab.getName() };
        return (new Expression( tab, Table.class, "new", constructorArgs ));
    }


    protected void initialize(Class type, Object oldInstance, 
                              Object newInstance, Encoder out) 
    {
        super.initialize(type, oldInstance, newInstance, out);


        Table tab = (Table)oldInstance;

        // Save the columns list
        Column[] cols = tab.getColumns();
        for (int i = 0; i < cols.length; i++) {
            Object[] args = new Object[] {cols[i]};
            out.writeStatement(new Statement(oldInstance, "addColumn", args));
        } // end of for ()

    }
    
}

