////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import java.awt.Component;
import java.awt.Rectangle;
import java.awt.BorderLayout;
import javax.swing.*;

import edu.uiuc.jdbv.schema.Column;

import net.javaprog.ui.DefaultCheckBoxListCellRenderer;

/**
 * The ColumnListRenderer returns rendering components to paint the cells
 * of the ColumnList.
 *
 * @author Brian Sidharta
 * @version $Revision: 1.3 $
 */
public class ColumnListRenderer extends DefaultCheckBoxListCellRenderer
{
    /** The filename for the key icon = "resources/key.gif" */
    public static final String KEY_ICON_FILENAME = "resources/key.gif";

    /** Our key icon */
    private static final Icon KEY_ICON = 
	new ImageIcon( ClassLoader.getSystemResource( KEY_ICON_FILENAME ));

    /** JComponent that displays the key icon */
    private static final JLabel KEY_LABEL = new JLabel( " ", KEY_ICON,
                                                        JLabel.LEFT );


    /**
     * JPanel that will contain the checkbox so we can show the key icon
     * to the right of the label.
     */
    private final JPanel KEY_PANEL;


    /** Default constructor */
    public ColumnListRenderer()
    {
        KEY_PANEL = new JPanel( new BorderLayout());
        KEY_PANEL.setOpaque( true );
    }


    /**
     * Return a component that has been configured to display the 
     * specified value
     */
    public Component getListCellRendererComponent( JList list, 
                                                   Object value,
                                                   int index, 
                                                   boolean isSelected,
                                                   boolean cellHasFocus )
    {
        Component comp = super.getListCellRendererComponent( list, value, 
                                                             index, isSelected, 
                                                             cellHasFocus );
        if( (comp instanceof JCheckBox) && 
            ( value instanceof Column ))
        {
            JCheckBox checkBox = (JCheckBox)comp;
            Column column = (Column)value;
            checkBox.setText( column.getName());
            if( column.isKey()) {
                KEY_PANEL.setForeground(isSelected ? 
                                        list.getSelectionForeground() : 
                                        list.getForeground());
                KEY_PANEL.setBackground(isSelected ? 
                                        list.getSelectionBackground() : 
                                        list.getBackground());
                KEY_PANEL.add( checkBox, BorderLayout.WEST );
                KEY_PANEL.add( KEY_LABEL, BorderLayout.CENTER );
                return (KEY_PANEL);
            }
        }

        return (comp);
    }



    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void validate() 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void revalidate() 
    {
    }
    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void repaint(long tm, int x, int y, int width, int height) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void repaint(Rectangle r) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    protected void firePropertyChange(String propertyName, Object oldValue, 
                                      Object newValue) 
    {
        // Strings get interned...
        if (propertyName=="text")
            super.firePropertyChange(propertyName, oldValue, newValue);
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, byte oldValue,
                                   byte newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, char oldValue,
                                   char newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, short oldValue,
                                   short newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, int oldValue, 
                                   int newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, long oldValue, 
                                   long newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, float oldValue,
                                   float newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, double oldValue, 
                                   double newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, boolean oldValue,
                                   boolean newValue) 
    {
    }



}

