////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import com.jgraph.event.*;

import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;

import java.util.*;
import javax.swing.event.*;
import java.awt.event.*;


/**
 * Event handler that captures mouse wheel events and performs
 * a zoom in or out on the existing diagram.
 *  
 * @author Brian Schoudel
 * @version $Revision: 1.6 $
 */
public class DiagramMouseWheelAdapter implements MouseWheelListener
{

    /** The JDBVWindow object passed in */
    private JDBVWindow currJDBVWindow;


    /**
     *  Constructor that takes the JDBV Window that it listens on
     *  
     * @param window the JDBVWindow
     */
    public DiagramMouseWheelAdapter( JDBVWindow window )
    {
        this.currJDBVWindow = window;

    }


    /** Handles when the Mouse Wheel is moved */
    public void mouseWheelMoved(MouseWheelEvent e)
    {

	StatusBar statbar = currJDBVWindow.getStatusBar();
	Diagram diagram = currJDBVWindow.getDiagramPane().getCurrentDiagram();
        if( diagram != null ) 
	{
	        double currentScale = diagram.getScale();
		int zoomDir = e.getWheelRotation();
		if ( zoomDir < 0 )
		{
			//zoom out
			diagram.setScale( 1.5 * currentScale );
			statbar.setZoom( 1.5 * currentScale );
		}
		else
		{
			//zoom in
			diagram.setScale( 0.667 * currentScale );
			statbar.setZoom( 0.667 * currentScale );
		}


	}	

    }


}

