////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import java.awt.*;
import java.text.NumberFormat;
import javax.swing.*;
import javax.swing.border.EtchedBorder;

/**
 * The status bar for the main GUI window
 *
 * @author Brian Sidharta
 * @version $Revision: 1.4 $
 */
public class StatusBar extends JPanel
{
    public static final NumberFormat ZOOM_FORMAT = 
        NumberFormat.getPercentInstance();

    private JLabel statusLabel;

    private JLabel zoomLabel;

    /** Default constructor */
    public StatusBar()
    {
        initComponents();
//         setStatus( null );
        setStatus( "Status text goes here." ); // TODO replace this   --Sid
        setZoom( 1.0f );
    }


    private void initComponents()
    {
        setLayout( new BorderLayout());

        statusLabel = new JLabel();
        statusLabel.setBorder( BorderFactory.createLoweredBevelBorder());

        zoomLabel = new JLabel();
        zoomLabel.setBorder( BorderFactory.createLoweredBevelBorder());
        
        add( statusLabel, BorderLayout.CENTER );
        add( zoomLabel, BorderLayout.EAST );
    }


    /** Sets the text to display on the status bar */
    public void setStatus( String message )
    {
        if( message == null || message.length() == 0 ) {
            message = " ";
        }

        statusLabel.setText( message );
    }


    /**
     * Sets the zoom text to display on the status bar
     * @param zoomFactor the scale of the graph, where 1.0 = normal zoom (100%)
     */
    public void setZoom( double zoomFactor )
    {
        String zoomStr = ZOOM_FORMAT.format( zoomFactor );
        zoomLabel.setText( zoomStr );
    }
}
