////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

import edu.uiuc.jdbv.JDBV;
import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;

import net.javaprog.ui.JCheckBoxList;


/**
 * Displays the list of tables in a schema, denoting diagram information.
 *  
 * @author Brian Sidharta
 * @version $Revision: 1.6 $
 */
public class TableList extends JCheckBoxList
{
    /** The logger to be used for the file = jdbv.JDBV */
    private static final org.apache.log4j.Logger LOG = 
        org.apache.log4j.Logger.getLogger("jdbv.gui.TableList");


    /** The checkbox width. TODO Need a better way to get this than hardcode */
    private static final int CHECKBOX_WIDTH = 20;


    /** The List Model for this table */
    private TableListModel model;


    /** Default constructor */
    public TableList()
    {
        super( new TableListModel());
        model = (TableListModel)getModel();
        setCellRenderer( new TableListRenderer());
    }



    /**
     * Sets the schema whose tables this table list is displaying.
     * @param schema the schema to use or <code>null</code> if there
     *        is no schema
     */
    public void setSchema( Schema schema )
    {
        setDiagram( null );
        model.setSchema( schema );
        repaint();

    }


    /**
     * Returns the schema whose tables this table list is displaying
     */
    public Schema getSchema()
    {
        return (model.getSchema());
    }



    /**
     * Sets the diagram whose information this table list is denoting.
     * @param diagram the diagram or <code>null</code> if there is no 
     *        diagram loaded
     */
    public void setDiagram( Diagram diagram )
    {
        setEnabled( diagram != null );
        model.setDiagram( diagram );
        repaint();
    }


    /**
     * Returns the diagram whose information this table list is showing.
     */
    public Diagram getDiagram()
    {
        return (model.getDiagram());
    }


    /**
     * Creates and returns a DiagramPane changeListener
     */
    public ChangeListener createChangeListener()
    {
        return (new DiagramSwitchListener());
    }


    /**
     * ChangeListener that handles when the user switches to a different
     * diagram.
     */
    class DiagramSwitchListener implements ChangeListener 
    {
        public void stateChanged( ChangeEvent e )
        {
            Object src = e.getSource();
            if (src instanceof DiagramPane) {
                DiagramPane diagramPane = (DiagramPane)src;
                Diagram diagram = diagramPane.getCurrentDiagram();
                model.setDiagram( diagram );
            } else {
                LOG.warn( "DiagramSwitchListener got event from a " + 
                          src.getClass());
            } // end of else
        }
    }

}

