////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
// ImportRegistry.java

package edu.uiuc.jdbv.imports;

/*<Imports>*/
import edu.uiuc.jdbv.JDBV;
import edu.uiuc.jdbv.schema.Schema;
import edu.uiuc.jdbv.gui.ImportRegistryWindow;


import java.util.*;
import java.net.URL;
import java.io.InputStream ;
/*</Imports>*/

/**
 * The ImportRegistry maintains a list of all implemented Schema import
 * classes derived from ImportDefinition. It reads the description  of 
 * the importers from a properties file and populates the File - import.. 
 * submenu with the list of available importers.
 *
 * @author Abhay Sathe
 * @author Ross Paul
 * @version $Revision: 1.13 $
 */
public class ImportRegistry
{

    // private fields

    /** Available ImportDefinitins read from IMPORT_PROPERTIES */ 
    private Vector definitionList; 

    /** The JDBV application instance that created this ImportSchemaAction */
    private JDBV jdbv;

    // Public constructors
    public ImportRegistry(JDBV jdbv, String fileLocation) {

        this.jdbv = jdbv ; 
        definitionList = new Vector();
        Properties defaultProps = new Properties();
	    
        // create and load default properties
        try {
            URL fileURL = ClassLoader.getSystemResource( fileLocation );
            InputStream in = fileURL.openStream();
            defaultProps.load( in );
            in.close();

            for(Enumeration enum = defaultProps.propertyNames();
                enum.hasMoreElements();){
                registerImportDefinition(defaultProps.getProperty
                                         ((String)enum.nextElement()));
            }

        } 
        catch(Exception e) {
            e.printStackTrace();
            //TODO Find a window to drop this info
        }
    }


    /** Uses reflection to load an instance of importName, then adds it to the
     *  importers list */
    private void registerImportDefinition(String importName) throws 
        ClassNotFoundException, InstantiationException, IllegalAccessException
    {
        Class importClass = Class.forName(importName);
        registerImportDefinition((ImportDefinition)importClass.newInstance());
    }
	
	

    /**
     * Adds the importDefinition to the importers list
     */
    public void registerImportDefinition (ImportDefinition def)  {
        definitionList.add(def) ;
    }

    public Vector getImporterList(){
        return definitionList;
    }

}
// end of ImportRegistry.java
