////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
// TorqueToDbviz.java
package edu.uiuc.jdbv.imports.sql;

/**
 * The class converts a torque table array and returns a dbViz
 * schema object
 *
 * @author Brian Schoudel
 * @version $Revision: 1.2 $
 */


/*<Imports>*/
import java.io.*;
import java.util.*;
import edu.uiuc.jdbv.imports.*;
import edu.uiuc.jdbv.schema.*;
import org.apache.torque.engine.database.model.Table;  //Table class
import org.apache.torque.engine.database.model.Column;  //Column class
import org.apache.torque.engine.database.model.ForeignKey;  //Foreign Key class
import org.apache.torque.engine.sql.ParseException; //Parser Exception
/*</Imports>*/


public class TorqueToDbviz
{
    private org.apache.torque.engine.database.model.Table[] tablesArray;
    private Schema sqlSchema;

    // Public constructors
    public TorqueToDbviz(org.apache.torque.engine.database.model.Table[] tablesArray){
    	this.tablesArray=tablesArray;
	sqlSchema = new Schema("sqlSchema");
    }


    /** convert the tables 
     *  from the torque schema to dbViz schema */
    public void convertTables()
    {
        //loop through the tables adding them to schema
	for (int i=0; i<tablesArray.length; i++)
	{
	  //set current table
          org.apache.torque.engine.database.model.Table currTable = tablesArray[i];
	  edu.uiuc.jdbv.schema.Table schemaTable = new edu.uiuc.jdbv.schema.Table(currTable.getName() );
	  sqlSchema.addTable(schemaTable); //add table to the schema

        }  //end table for loop

    }


    /** convert the columns 
     *  from the torque schema to dbViz schema */
    public void convertColumns()
    {
        //loop through the tables adding columns to the schema
	for (int i=0; i<tablesArray.length; i++)
	{
	  //set current table
          org.apache.torque.engine.database.model.Table currTable = tablesArray[i];
	  Column[] columnsArray = currTable.getColumns();

	    //loop to add columns to table
	    for (int j=0; j<columnsArray.length; j++)
	    {
	      
	      StringBuffer dataType = new StringBuffer();  //String for datatype of column
	      dataType.append(columnsArray[j].getType().toString() ).append(columnsArray[j].printSize() );

	      edu.uiuc.jdbv.schema.Column schemaCol = new edu.uiuc.jdbv.schema.Column(columnsArray[j].getName(), dataType.toString(), columnsArray[j].isPrimaryKey() );
	      sqlSchema.getTable(currTable.getName() ).addColumn(schemaCol);
	    } //end second for loop

        }  //end table for loop

    }


    /** convert the foreign keys 
     *  from the torque schema to dbViz schema */
    public void convertForeignKeys()
    {
        //loop through the tables adding columns to the schema
	for (int i=0; i<tablesArray.length; i++)
	{
	  //set current table
          org.apache.torque.engine.database.model.Table currTable = tablesArray[i];

	    //foreign key section
	    ForeignKey[] fkArray = currTable.getForeignKeys();
	    for (int k=0; k<fkArray.length; k++)
	    {
	      ForeignKey currFK = fkArray[k];  //set current foreign key

	      Iterator foreignCols = currFK.getForeignColumns().iterator();
	      edu.uiuc.jdbv.schema.Column[] foreignColArray = new edu.uiuc.jdbv.schema.Column[currFK.getForeignColumns().size()];
	      int l = 0;
	      while (foreignCols.hasNext())
              {
                //populate the independant column array
                foreignColArray[l]=sqlSchema.getTable(currFK.getForeignTableName() ).getColumn( (String) foreignCols.next() );
	        l++;
	      }

	      Iterator localCols = currFK.getLocalColumns().iterator();
	      edu.uiuc.jdbv.schema.Column[] localColArray = new edu.uiuc.jdbv.schema.Column[currFK.getLocalColumns().size()];
	      int m = 0;
	      while (localCols.hasNext())
              {
                //populate the dependant column array
	        localColArray[m]=sqlSchema.getTable(currFK.getTableName() ).getColumn( (String) localCols.next() );
	        m++;
	      }

	      //create connection
	      Connection.linkTables(sqlSchema.getTable(currFK.getForeignTableName() ), sqlSchema.getTable(currFK.getTableName() ), foreignColArray, localColArray);
	      

	    } //end foreign key for loop

        }  //end table for loop

    }

    
    /** Convert the torque schema 
     *  to dbViz schema object and return it */
    public Schema convert()
    {
	convertTables();
	convertColumns();
	convertForeignKeys();
        return sqlSchema;
    }



}
// end of TorqueToDbviz.java

