////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.util;

import java.util.*;

/**
 * Miscellaneous Collection utility functions.
 * @author Brian Sidharta
 * @version $Revision: 1.3 $
 */
public class CollectionUtils
{
    /** Private to prevent instantiation */
    private CollectionUtils()
    {}


    /**
     * Returns whether two lists and their items are identical 
     * @param l1 the first list; should never be null
     * @param l2 the second list; should never be null
     */
    public static boolean listsEqual( List l1, List l2 )
    {
        // Do fast size check first
        if( l1.size() != l2.size()) {
            return (false);
        }
        
        Object[] objs1 = l1.toArray( new Object[l1.size()] );
        Object[] objs2 = l2.toArray( new Object[l2.size()] );

        return (Arrays.equals( objs1, objs2 ));
    }


    /**
     * Returns whether two maps and their items are identical.
     * @param m1 the first map; should never be null
     * @param m2 the second map; should never be null
     * @throws Exception if an error occurs while comparing
     */
    public static boolean mapsEqual( Map m1, Map m2 )
    {
        if( m1.size() != m2.size()) {
            return (false);
        }

        Iterator it1 = m1.keySet().iterator();
        while( it1.hasNext()) {
            Object key = it1.next();
            Object o1 = m1.get( key );
            Object o2 = m2.get( key );
            if( o1 != null ) {
                if( !o1.equals( o2 )) {
                    return (false);
                }
            } else if( o2 != null ) {
                return (false);
            }
        }
        return (true);
    }


}

